==> smart-wx-service-20.2.2-sources.jar: net/guerlab/smart/wx/service/service/impl/WxMpLoginServiceImpl.java <==
package net.guerlab.smart.wx.service.service.impl;

import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpOAuth2AccessToken;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import net.guerlab.commons.exception.ApplicationException;
import net.guerlab.smart.platform.auth.factory.TokenFactory;
import net.guerlab.smart.wx.core.domain.LoginResponse;
import net.guerlab.smart.wx.core.entity.IWxUserTokenInfo;
import net.guerlab.smart.wx.core.exception.CodeInvalidException;
import net.guerlab.smart.wx.service.entity.WxApp;
import net.guerlab.smart.wx.service.entity.WxUser;
import net.guerlab.smart.wx.service.service.WxMpLoginService;
import net.guerlab.smart.wx.service.service.WxMpManagerService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * 微信公众号登录服务实现
 *
 * @author guer
 */
@Service
public class WxMpLoginServiceImpl extends AbstractWxLoginServiceImpl implements WxMpLoginService {

    private WxMpManagerService managerService;

    @Override
    public LoginResponse login(String appId, String code, String ip, String referer,
            TokenFactory<IWxUserTokenInfo> tokenFactory) {
        if (StringUtils.isBlank(code)) {
            throw new CodeInvalidException();
        }

        WxApp wxApp = getWxApp(appId);
        WxMpService wxMpService = getWxMpService(appId);
        WxMpUser wxMpUser;

        try {
            WxMpOAuth2AccessToken oAuth2AccessToken = wxMpService.oauth2getAccessToken(code);
            wxMpUser = wxMpService.oauth2getUserInfo(oAuth2AccessToken, "zh_CN");
        } catch (WxErrorException e) {
            throw new ApplicationException(e.getError().getErrorMsg(), e, e.getError().getErrorCode());
        }

        String unionId = wxMpUser.getUnionId();
        String openId = wxMpUser.getOpenId();

        WxUser wxUser = wxUserService.findUser(appId, openId);
        if (wxUser == null) {
            LocalDateTime now = LocalDateTime.now();
            wxUser = new WxUser();
            wxUser.setOpenId(openId);
            wxUser.setAppId(appId);
            wxUser.setAppName(wxApp.getAppName());
            wxUser.setUnionId(unionId);
            wxUser.setAvatarUrl(wxMpUser.getHeadImgUrl());
            wxUser.setNickName(wxMpUser.getNickname());
            wxUser.setRegistryTime(now);
            wxUser.setLastLoginTime(now);
            wxUser.setActivated(true);
            wxUserService.insertSelective(wxUser);
            wxUserLoginLogService.addLog(wxUser, ip, referer);
        } else {
            wxUser.setActivated(true);
            updateUserInfo(wxUser, openId, unionId, true, ip, referer);
        }

        return buildLoginResponse(wxUser, tokenFactory, ip);
    }

    private WxMpService getWxMpService(String appId) {
        return managerService.getService(appId);
    }

    @Autowired
    public void setManagerService(WxMpManagerService managerService) {
        this.managerService = managerService;
    }
}

==> smart-wx-service-21.4.0-sources.jar: net/guerlab/smart/wx/service/service/impl/WxMpLoginServiceImpl.java <==
/*
 * Copyright 2018-2021 guerlab.net and other contributors.
 *
 * Licensed under the GNU LESSER GENERAL PUBLIC LICENSE, Version 3 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.guerlab.smart.wx.service.service.impl;

import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpOAuth2AccessToken;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import net.guerlab.commons.exception.ApplicationException;
import net.guerlab.smart.platform.auth.factory.TokenFactory;
import net.guerlab.smart.wx.core.domain.LoginResponse;
import net.guerlab.smart.wx.core.entity.IWxUserTokenInfo;
import net.guerlab.smart.wx.core.exception.CodeInvalidException;
import net.guerlab.smart.wx.service.entity.WxApp;
import net.guerlab.smart.wx.service.entity.WxUser;
import net.guerlab.smart.wx.service.service.WxMpLoginService;
import net.guerlab.smart.wx.service.service.WxMpManagerService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * 微信公众号登录服务实现
 *
 * @author guer
 */
@Service
public class WxMpLoginServiceImpl extends AbstractWxLoginServiceImpl implements WxMpLoginService {

    private WxMpManagerService managerService;

    @Override
    public LoginResponse login(String appId, String code, String ip, String referer, TokenFactory<IWxUserTokenInfo> tokenFactory) {
        if (StringUtils.isBlank(code)) {
            throw new CodeInvalidException();
        }

        WxApp wxApp = getWxApp(appId);
        WxMpService wxMpService = getWxMpService(appId);
        WxMpUser wxMpUser;

        try {
            WxMpOAuth2AccessToken oAuth2AccessToken = wxMpService.oauth2getAccessToken(code);
            wxMpUser = wxMpService.oauth2getUserInfo(oAuth2AccessToken, "zh_CN");
        } catch (WxErrorException e) {
            throw new ApplicationException(e.getError().getErrorMsg(), e, e.getError().getErrorCode());
        }

        String unionId = wxMpUser.getUnionId();
        String openId = wxMpUser.getOpenId();

        WxUser wxUser = wxUserService.findUser(appId, openId);
        if (wxUser == null) {
            LocalDateTime now = LocalDateTime.now();
            wxUser = new WxUser();
            wxUser.setOpenId(openId);
            wxUser.setAppId(appId);
            wxUser.setAppName(wxApp.getAppName());
            wxUser.setUnionId(unionId);
            wxUser.setAvatarUrl(wxMpUser.getHeadImgUrl());
            wxUser.setNickName(wxMpUser.getNickname());
            wxUser.setRegistryTime(now);
            wxUser.setLastLoginTime(now);
            wxUser.setActivated(true);
            wxUserService.insert(wxUser);
            wxUserLoginLogService.addLog(wxUser, ip, referer);
        } else {
            wxUser.setActivated(true);
            updateUserInfo(wxUser, openId, unionId, true, ip, referer);
        }

        return buildLoginResponse(wxUser, tokenFactory, ip);
    }

    private WxMpService getWxMpService(String appId) {
        return managerService.getService(appId);
    }

    @Autowired
    public void setManagerService(WxMpManagerService managerService) {
        this.managerService = managerService;
    }
}
